@@ -1,4 +1,4 @@
-/* $Id: vserver.h 2415 2006-12-08 13:24:49Z dhozac $
+/* $Id: vserver.h 2501 2007-02-20 17:33:35Z dhozac $
 
 *  Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 *   
@@ -225,6 +225,7 @@
 
 #define VC_VXSM_IDLE_TIME		0x0200
 #define VC_VXSM_FORCE			0x0400
+#define VC_VXSM_MSEC			0x4000
 
 #define VC_VXSM_V3_MASK			0x0173
 
@@ -260,6 +261,18 @@
 #define VC_VCI_SPACES			(1 << 10)
 
 
+// the device mapping flags
+#define VC_DATTR_CREATE			0x00000001
+#define VC_DATTR_OPEN			0x00000002
+
+#define VC_DATTR_REMAP			0x00000010
+
+
+// the process context migration flags
+#define VC_VXM_SET_INIT			0x00000001
+#define VC_VXM_SET_REAPER		0x00000002
+
+
 #ifndef CLONE_NEWNS
 #  define CLONE_NEWNS			0x00020000
 #endif
@@ -293,11 +306,6 @@ typedef an_unsigned_integer_type	nid_t;
 extern "C" {
 #endif
 
-  struct vc_ip_mask_pair {
-      uint32_t	ip;
-      uint32_t	mask;
-  };
-
     /** \brief   The generic vserver syscall
      *  \ingroup syscalls
      *
@@ -310,20 +318,20 @@ extern "C" {
      *  \param   data additional arguments; depends on \c cmd
      *  \returns depends on \c cmd; usually, -1 stands for an error
      */
-  int	vc_syscall(uint32_t cmd, xid_t xid, void *data);
+  int		vc_syscall(uint32_t cmd, xid_t xid, void *data);
 
     /** \brief   Returns the version of the current kernel API.
      *  \ingroup syscalls
      *	\returns The versionnumber of the kernel API
      */
-  int	vc_get_version();
+  int		vc_get_version();
 
     /** \brief   Returns the kernel configuration bits
      *  \ingroup syscalls
      *  \returns The kernel configuration bits
      */
-  int   vc_get_vci();
-  
+  int		vc_get_vci();
+
     /** \brief   Moves current process into a context
      *  \ingroup syscalls
      *
@@ -341,12 +349,17 @@ extern "C" {
      *	          will be set appropriately
      *
      *  See http://vserver.13thfloor.at/Stuff/Logic.txt for details */
-  xid_t	vc_new_s_context(xid_t ctx, unsigned int remove_cap, unsigned int flags);
+  xid_t		vc_new_s_context(xid_t ctx, unsigned int remove_cap, unsigned int flags);
+
+  struct vc_ip_mask_pair {
+      uint32_t	ip;
+      uint32_t	mask;
+  };
 
     /** \brief  Sets the ipv4root information.
      *  \ingroup syscalls
      *  \pre    \a nb < NB_IPV4ROOT && \a ips != 0 */
-  int	vc_set_ipv4root(uint32_t  bcast, size_t nb,
+  int		vc_set_ipv4root(uint32_t  bcast, size_t nb,
 			struct vc_ip_mask_pair const *ips) VC_ATTR_NONNULL((3));
 
     /** \brief  Returns the value of NB_IPV4ROOT.
@@ -357,6 +370,18 @@ extern "C" {
      *  running kernel. */
   size_t	vc_get_nb_ipv4root() VC_ATTR_CONST VC_ATTR_PURE;
 
+    /* process context */
+  /** \brief    Flags of process-contexts
+   */
+  struct  vc_ctx_flags {
+      /** \brief Mask of set context flags */
+      uint_least64_t	flagword;
+      /** \brief Mask of set and unset context flags when used by set
+       *         operations, or modifiable flags when used by get
+       *         operations */
+      uint_least64_t	mask;
+  };
+
     /** \brief   Creates a context without starting it.
      *  \ingroup syscalls
      *
@@ -368,14 +393,15 @@ extern "C" {
      *
      *	\returns the xid of the created context, or VC_NOCTX on errors. \c errno
      *	         will be set appropriately. */
-  xid_t	vc_ctx_create(xid_t xid);
+  xid_t		vc_ctx_create(xid_t xid);
 
     /** \brief   Moves the current process into the specified context.
      *  \ingroup syscalls
      *
-     *  \param   xid  The new context
+     *  \param   xid    The new context
+     *  \param   flags  The flags, see VC_VXM_*
      *  \returns 0 on success, -1 on errors */
-  int	vc_ctx_migrate(xid_t xid);
+  int		vc_ctx_migrate(xid_t xid, uint_least64_t flags);
 
     /** \brief   Statistics about a context */
   struct vc_ctx_stat {
@@ -390,12 +416,12 @@ extern "C" {
      *  \param   stat  Where to store the result
      *
      *  \returns 0 on success, -1 on errors. */
-  int   vc_ctx_stat(xid_t xid, struct vc_ctx_stat /*@out@*/ *stat) VC_ATTR_NONNULL((2));
+  int		vc_ctx_stat(xid_t xid, struct vc_ctx_stat /*@out@*/ *stat) VC_ATTR_NONNULL((2));
 
     /** \brief   Contains further statistics about a context. */
   struct vc_virt_stat {
       uint_least64_t	offset;
-      uint_least32_t	uptime;
+      uint_least64_t	uptime;
       uint_least32_t	nr_threads;
       uint_least32_t	nr_running;
       uint_least32_t	nr_uninterruptible;
@@ -411,7 +437,58 @@ extern "C" {
      *  \param stat  Where to store the result
      *
      *  \returns 0 on success, -1 on errors. */
-  int   vc_virt_stat(xid_t xid, struct vc_virt_stat /*@out@*/ *stat) VC_ATTR_NONNULL((2));
+  int		vc_virt_stat(xid_t xid, struct vc_virt_stat /*@out@*/ *stat) VC_ATTR_NONNULL((2));
+
+  /** \brief    Sends a signal to a context/pid
+   *  \ingroup  syscalls
+   *
+   *  Special values for \a pid are:
+   *  - -1   which means every process in ctx except the init-process
+   *  -  0   which means every process in ctx inclusive the init-process */
+  int		vc_ctx_kill(xid_t ctx, pid_t pid, int sig);
+ 
+  int		vc_get_cflags(xid_t xid, struct vc_ctx_flags /*@out@*/ *)	VC_ATTR_NONNULL((2));
+  int		vc_set_cflags(xid_t xid, struct vc_ctx_flags /*@in@*/ const *)	VC_ATTR_NONNULL((2));
+
+  /** \brief    Capabilities of process-contexts */
+  struct  vc_ctx_caps {
+      /** \brief  Mask of set common system capabilities */
+      uint_least64_t	bcaps;
+      /** \brief Mask of set and unset common system capabilities when used by
+       *         set operations, or the modifiable capabilities when used by
+       *         get operations */
+      uint_least64_t	bmask;
+      /** \brief Mask of set process context capabilities */
+      uint_least64_t	ccaps;
+      /** \brief Mask of set and unset process context capabilities when used
+       *         by set operations, or the modifiable capabilities when used
+       *         by get operations */
+      uint_least64_t	cmask;
+  };
+
+  int		vc_get_ccaps(xid_t xid, struct vc_ctx_caps *);
+  int		vc_set_ccaps(xid_t xid, struct vc_ctx_caps const *);
+
+  struct vc_vx_info {
+      xid_t	xid;
+      pid_t	initpid;
+  };
+
+  int		vc_get_vx_info(xid_t xid, struct vc_vx_info *info) VC_ATTR_NONNULL((2));
+  
+    /** \brief   Returns the context of the given process.
+     *  \ingroup syscalls
+     *
+     *  \param  pid  the process-id whose xid shall be determined;
+     *               pid==0 means the current process.
+     *  \returns     the xid of process \c pid or -1 on errors
+     */
+  xid_t		vc_get_task_xid(pid_t pid);
+
+  /** \brief   Waits for the end of a context
+   *  \ingroup syscalls
+   */
+  int		vc_wait_exit(xid_t xid);
   
     /* rlimit related functions */
   
@@ -426,15 +503,6 @@ extern "C" {
      *  resource; it might be bytes, pages, seconds or litres of beer. */
   typedef uint_least64_t	vc_limit_t;
 
-    /** \brief  The limits of a resources.
-     *
-     *  This is a triple consisting of a minimum, soft and hardlimit. */
-  struct vc_rlimit {
-      vc_limit_t	min;	///< the guaranted minimum of a resources
-      vc_limit_t	soft;	///< the softlimit of a resource
-      vc_limit_t	hard;	///< the absolute hardlimit of a resource
-  };
-
     /** \brief  Masks describing the supported limits. */
   struct  vc_rlimit_mask {
       uint_least32_t	min;	///< masks the resources supporting a minimum limit
@@ -442,12 +510,17 @@ extern "C" {
       uint_least32_t	hard;	///< masks the resources supporting a hard limit
   };
 
-    /** \brief Statistics for a resource limit. */
-  struct  vc_rlimit_stat {
-      uint_least32_t	hits;	 ///< number of hits on the limit
-      uint_least64_t	value;	 ///< current value
-      uint_least64_t	minimum; ///< minimum value observed
-      uint_least64_t	maximum; ///< maximum value observed
+    /** \brief  Returns the limits supported by the kernel */
+  int		vc_get_rlimit_mask(xid_t xid,
+			   struct vc_rlimit_mask /*@out@*/ *lim) VC_ATTR_NONNULL((2));
+
+    /** \brief  The limits of a resources.
+     *
+     *  This is a triple consisting of a minimum, soft and hardlimit. */
+  struct vc_rlimit {
+      vc_limit_t	min;	///< the guaranted minimum of a resources
+      vc_limit_t	soft;	///< the softlimit of a resource
+      vc_limit_t	hard;	///< the absolute hardlimit of a resource
   };
 
     /** \brief   Returns the limits of \a resource.
@@ -458,7 +531,7 @@ extern "C" {
      *  \param  lim       The result which will be filled with the limits
      *
      *  \returns 0 on success, and -1 on errors. */
-  int	vc_get_rlimit(xid_t xid, int resource,
+  int		vc_get_rlimit(xid_t xid, int resource,
 		      struct vc_rlimit       /*@out@*/ *lim) VC_ATTR_NONNULL((3));
     /** \brief   Sets the limits of \a resource.
      *  \ingroup syscalls
@@ -468,10 +541,17 @@ extern "C" {
      *  \param  lim       The new limits
      *
      *  \returns 0 on success, and -1 on errors. */
-  int	vc_set_rlimit(xid_t xid, int resource,
+  int		vc_set_rlimit(xid_t xid, int resource,
 		      struct vc_rlimit const /*@in@*/  *lim) VC_ATTR_NONNULL((3));
-  int	vc_get_rlimit_mask(xid_t xid,
-			   struct vc_rlimit_mask *lim)       VC_ATTR_NONNULL((2));
+
+    /** \brief Statistics for a resource limit. */
+  struct  vc_rlimit_stat {
+      uint_least32_t	hits;	 ///< number of hits on the limit
+      vc_limit_t	value;	 ///< current value
+      vc_limit_t	minimum; ///< minimum value observed
+      vc_limit_t	maximum; ///< maximum value observed
+  };
+
     /** \brief   Returns the current stats of \a resource.
      *  \ingroup syscalls
      *
@@ -480,15 +560,17 @@ extern "C" {
      *  \param  stat      The result which will be filled with the stats
      *
      *  \returns 0 on success, and -1 on errors. */
-  int   vc_rlimit_stat(xid_t xid, int resource,
+  int		vc_rlimit_stat(xid_t xid, int resource,
 		       struct vc_rlimit_stat /*@out@*/ *stat) VC_ATTR_NONNULL((3));
-    /** \brief   Resets the minimum and maximum observed values for all resources.
+
+    /** \brief   Resets the minimum and maximum observed values of all resources.
      *  \ingroup syscalls
      *
-     *  \param xid  The id of the context
+     *  \param xid	The id of the context
      *
      *  \returns 0 on success, and -1 on errors. */
-  int   vc_reset_minmax(xid_t xid);
+  int		vc_reset_minmax(xid_t xid);
+
     /** \brief   Parses a string describing a limit
      *  \ingroup helper
      *
@@ -508,18 +590,10 @@ extern "C" {
      *
      *  \pre \a str!=0 && \a res!=0
      */
-  bool	vc_parseLimit(char const /*@in@*/ *str, vc_limit_t /*@out@*/ *res)	VC_ATTR_NONNULL((1,2));
-
-
-  /** \brief    Sends a signal to a context/pid
-   *  \ingroup  syscalls
-   *
-   *  Special values for \a pid are:
-   *  - -1   which means every process in ctx except the init-process
-   *  -  0   which means every process in ctx inclusive the init-process */
-  int	vc_ctx_kill(xid_t ctx, pid_t pid, int sig);
+  bool		vc_parseLimit(char const /*@in@*/ *str, vc_limit_t /*@out@*/ *res)	VC_ATTR_NONNULL((1,2));
 
 
+    /* network context */
   struct vc_nx_info {
       nid_t	nid;
   };
@@ -538,21 +612,20 @@ extern "C" {
       uint32_t		mask[4];
   };
 
+  struct vc_net_flags {
+      uint_least64_t	flagword;
+      uint_least64_t	mask;
+  };
+
   nid_t		vc_net_create(nid_t nid);
   int		vc_net_migrate(nid_t nid);
 
   int		vc_net_add(nid_t nid, struct vc_net_nx const *info);
   int		vc_net_remove(nid_t nid, struct vc_net_nx const *info);
 
-  struct vc_net_flags {
-      uint_least64_t	flagword;
-      uint_least64_t	mask;
-  };
-  
   int		vc_get_nflags(nid_t, struct vc_net_flags *);
   int		vc_set_nflags(nid_t, struct vc_net_flags const *);
 
-  
   struct vc_net_caps {
       uint_least64_t	ncaps;
       uint_least64_t	cmask;
@@ -562,7 +635,7 @@ extern "C" {
   int		vc_set_ncaps(nid_t, struct vc_net_caps const *);
 
 
-  
+    /* iattr related functions */
 
   int		vc_set_iattr(char const *filename, xid_t xid,
 			     uint_least32_t flags, uint_least32_t mask) VC_ATTR_NONNULL((1));
@@ -596,23 +669,24 @@ extern "C" {
   int		vc_get_iattr(char const *filename, xid_t * /*@null@*/ xid,
 			     uint_least32_t * /*@null@*/ flags,
 			     uint_least32_t * /*@null@*/ mask) VC_ATTR_NONNULL((1));
-
-  struct vc_vx_info {
-      xid_t	xid;
-      pid_t	initpid;
-  };
   
-    /** \brief   Returns the context of the given process.
-     *  \ingroup syscalls
-     *
-     *  \param  pid  the process-id whose xid shall be determined;
-     *               pid==0 means the current process.
-     *  \returns     the xid of process \c pid or -1 on errors
-     */
-  xid_t		vc_get_task_xid(pid_t pid);
-  int		vc_get_vx_info(xid_t xid, struct vc_vx_info *info) VC_ATTR_NONNULL((2));
+  /** \brief   Returns the context of \c filename
+   *  \ingroup syscalls
+   *
+   *  This function calls vc_get_iattr() with appropriate arguments to
+   *  determine the context of \c filename. In error-case or when no context
+   *  is assigned, \c VC_NOCTX will be returned. To differ between both cases,
+   *  \c errno must be examined.
+   *
+   *  \b WARNING: this function can modify \c errno although no error happened.
+   *
+   *  \param   filename  The file to check
+   *  \returns The assigned context, or VC_NOCTX when an error occured or no
+   *           such assignment exists. \c errno will be 0 in the latter case */
+  xid_t		vc_getfilecontext(char const *filename) VC_ATTR_NONNULL((1));
 
 
+    /* vhi related functions */
   typedef enum { vcVHI_CONTEXT, vcVHI_SYSNAME, vcVHI_NODENAME,
 		 vcVHI_RELEASE, vcVHI_VERSION, vcVHI_MACHINE,
 		 vcVHI_DOMAINNAME }		vc_uts_type;
@@ -622,42 +696,72 @@ extern "C" {
   int		vc_get_vhi_name(xid_t xid, vc_uts_type type,
 				char *val, size_t len)       VC_ATTR_NONNULL((3));
 
-    /** Returns true iff \a xid is a dynamic xid */
-  bool		vc_is_dynamic_xid(xid_t xid);
-
+    /* namespace related functions */
   int		vc_enter_namespace(xid_t xid, uint_least64_t mask);
   int		vc_set_namespace(xid_t xid, uint_least64_t mask);
   int		vc_cleanup_namespace();
   uint_least64_t vc_get_space_mask();
 
+
+    /* disk limit related things */
+  struct vc_ctx_dlimit {
+      uint_least32_t	space_used;
+      uint_least32_t	space_total;
+      uint_least32_t	inodes_used;
+      uint_least32_t	inodes_total;
+      uint_least32_t	reserved;
+  };
   
-  /** \brief    Flags of process-contexts
-   */
-  struct  vc_ctx_flags {
-      /** \brief Mask of set context flags */
-      uint_least64_t	flagword;
-      /** \brief Mask of set and unset context flags when used by set
-       *         operations, or modifiable flags when used by get
-       *         operations */
-      uint_least64_t	mask;
+
+  /** Add a disk limit to a file system. */
+  int		vc_add_dlimit(char const *filename, xid_t xid,
+			      uint_least32_t flags) VC_ATTR_NONNULL((1));
+  /** Remove a disk limit from a file system. */
+  int		vc_rem_dlimit(char const *filename, xid_t xid,
+			      uint_least32_t flags) VC_ATTR_NONNULL((1));
+
+  /** Set a disk limit. */
+  int		vc_set_dlimit(char const *filename, xid_t xid,
+			      uint_least32_t flags,
+			      struct vc_ctx_dlimit const *limits) VC_ATTR_NONNULL((1,4));
+  /** Get a disk limit. */
+  int		vc_get_dlimit(char const *filename, xid_t xid,
+			      uint_least32_t flags,
+			      struct vc_ctx_dlimit *limits) VC_ATTR_NONNULL((1));
+
+    /* scheduler related syscalls */
+  struct vc_set_sched {
+      uint_least32_t	set_mask;
+      int_least32_t	fill_rate;
+      int_least32_t	interval;
+      int_least32_t	fill_rate2;
+      int_least32_t	interval2;
+      int_least32_t	tokens;
+      int_least32_t	tokens_min;
+      int_least32_t	tokens_max;
+      int_least32_t	priority_bias;
+      int_least32_t	cpu_id;
+      int_least32_t	bucket_id;
   };
 
-  /** \brief    Capabilities of process-contexts */
-  struct  vc_ctx_caps {
-      /** \brief  Mask of set common system capabilities */
-      uint_least64_t	bcaps;
-      /** \brief Mask of set and unset common system capabilities when used by
-       *         set operations, or the modifiable capabilities when used by
-       *         get operations */
-      uint_least64_t	bmask;
-      /** \brief Mask of set process context capabilities */
-      uint_least64_t	ccaps;
-      /** \brief Mask of set and unset process context capabilities when used
-       *         by set operations, or the modifiable capabilities when used
-       *         by get operations */
-      uint_least64_t	cmask;
+  int		vc_set_sched(xid_t xid, struct vc_set_sched const *) VC_ATTR_NONNULL((2));
+
+  struct vc_sched_info {
+      int_least32_t	cpu_id;
+      int_least32_t	bucket_id;
+      uint_least64_t	user_msec;
+      uint_least64_t	sys_msec;
+      uint_least64_t	hold_msec;
+      uint_least32_t	token_usec;
+      int_least32_t	vavavoom;
   };
 
+  int		vc_sched_info(xid_t xid, struct vc_sched_info *info) VC_ATTR_NONNULL((2));
+
+    /* misc. syscalls */
+  int		vc_set_mapping(xid_t xid, const char *device, const char *target, uint32_t flags);
+
+
   /** \brief    Information about parsing errors
    *  \ingroup  helper
    */
@@ -665,12 +769,6 @@ extern "C" {
       char const	*ptr;		///< Pointer to the first character of an erroneous string
       size_t		len;		///< Length of the erroneous string
   };
- 
-  int			vc_get_cflags(xid_t xid, struct vc_ctx_flags *)       VC_ATTR_NONNULL((2));
-  int			vc_set_cflags(xid_t xid, struct vc_ctx_flags const *) VC_ATTR_NONNULL((2));
-
-  int			vc_get_ccaps(xid_t xid, struct vc_ctx_caps *);
-  int			vc_set_ccaps(xid_t xid, struct vc_ctx_caps const *);
 
   /** \brief   Converts a single string into bcapability
    *  \ingroup helper
@@ -786,75 +884,13 @@ extern "C" {
 
   uint_least32_t	vc_str2personalitytype(char const /*@in@*/*,
 					       size_t len) VC_ATTR_NONNULL((1));
-  
-  /** \brief   Returns the context of \c filename
-   *  \ingroup syscalls
-   *
-   *  This function calls vc_get_iattr() with appropriate arguments to
-   *  determine the context of \c filename. In error-case or when no context
-   *  is assigned, \c VC_NOCTX will be returned. To differ between both cases,
-   *  \c errno must be examined.
-   *
-   *  \b WARNING: this function can modify \c errno although no error happened.
-   *
-   *  \param   filename  The file to check
-   *  \returns The assigned context, or VC_NOCTX when an error occured or no
-   *           such assignment exists. \c errno will be 0 in the latter case */
-  xid_t		vc_getfilecontext(char const *filename) VC_ATTR_NONNULL((1));
 
-
-  struct vc_set_sched {
-      uint_least32_t	set_mask;
-      int_least32_t	fill_rate;
-      int_least32_t	interval;
-      int_least32_t	fill_rate2;
-      int_least32_t	interval2;
-      int_least32_t	tokens;
-      int_least32_t	tokens_min;
-      int_least32_t	tokens_max;
-      int_least32_t	priority_bias;
-      int_least32_t	cpu_id;
-      int_least32_t	bucket_id;
-  };
-
-  int		vc_set_sched(xid_t xid, struct vc_set_sched const *);
-
-
-  struct vc_ctx_dlimit {
-      uint_least32_t	space_used;
-      uint_least32_t	space_total;
-      uint_least32_t	inodes_used;
-      uint_least32_t	inodes_total;
-      uint_least32_t	reserved;
-  };
-  
-
-  /** Add a disk limit to a file system. */
-  int		vc_add_dlimit(char const *filename, xid_t xid,
-			      uint_least32_t flags) VC_ATTR_NONNULL((1));
-  /** Remove a disk limit from a file system. */
-  int		vc_rem_dlimit(char const *filename, xid_t xid,
-			      uint_least32_t flags) VC_ATTR_NONNULL((1));
-
-  /** Set a disk limit. */
-  int		vc_set_dlimit(char const *filename, xid_t xid,
-			      uint_least32_t flags,
-			      struct vc_ctx_dlimit const *limits) VC_ATTR_NONNULL((1,4));
-  /** Get a disk limit. */
-  int		vc_get_dlimit(char const *filename, xid_t xid,
-			      uint_least32_t flags,
-			      struct vc_ctx_dlimit *limits) VC_ATTR_NONNULL((1));
-
-  /** \brief   Waits for the end of a context
-   *  \ingroup syscalls
-   */
-  int		vc_wait_exit(xid_t xid);
     
   typedef enum { vcFEATURE_VKILL,  vcFEATURE_IATTR,   vcFEATURE_RLIMIT,
 		 vcFEATURE_COMPAT, vcFEATURE_MIGRATE, vcFEATURE_NAMESPACE,
 		 vcFEATURE_SCHED,  vcFEATURE_VINFO,   vcFEATURE_VHI,
                  vcFEATURE_VSHELPER0, vcFEATURE_VSHELPER, vcFEATURE_VWAIT,
-		 vcFEATURE_VNET }
+		 vcFEATURE_VNET, vcFEATURE_VSTAT }
     vcFeatureSet;
 
   bool		vc_isSupported(vcFeatureSet) VC_ATTR_CONST;
@@ -867,6 +903,10 @@ extern "C" {
   
   vcXidType	vc_getXIDType(xid_t xid) VC_ATTR_CONST;
 
+    /** Returns true iff \a xid is a dynamic xid */
+  bool		vc_is_dynamic_xid(xid_t xid);
+
+
   /* The management part */
 
 #define VC_LIMIT_VSERVER_NAME_LEN	1024
