@@ -1,4 +1,4 @@
-// $Id: chcontext.c,v 1.26 2006/01/22 19:31:53 ensc Exp $
+// $Id: chcontext.c 2403 2006-11-24 23:06:08Z dhozac $
 
 // Copyright (C) 2003,2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 // based on chcontext.cc by Jacques Gelinas
@@ -339,7 +339,7 @@ int main (int argc, char *argv[])
       default		:
 	WRITE_MSG(2, "Try '");
 	WRITE_STR(2, argv[0]);
-	WRITE_MSG(2, " --help\" for more information.\n");
+	WRITE_MSG(2, " --help' for more information.\n");
 	return 255;
 	break;
     }
